Function glob_builder
fn glob_builder<S: AsRef<str>>(pattern: S) -> GlobWalkerBuilder
Construct a new GlobWalkerBuilder with a glob pattern.
When iterated, the current directory will be recursively searched for paths
matching pattern, unless the pattern specifies an absolute path.