Struct GlobWalker

struct GlobWalker { ... }

An iterator which emits glob-matched patterns.

An instance of this type must be constructed through GlobWalker, which uses a builder-style pattern.

The order of the yielded paths is undefined, unless specified by the user using GlobWalker::sort_by.

Implementations

impl Freeze for GlobWalker

impl Iterator for GlobWalker

fn next(self: &mut Self) -> Option<<Self as >::Item>

impl RefUnwindSafe for GlobWalker

impl Send for GlobWalker

impl Sync for GlobWalker

impl Unpin for GlobWalker

impl UnsafeUnpin for GlobWalker

impl UnwindSafe for GlobWalker

impl<I> IntoIterator for GlobWalker

fn into_iter(self: Self) -> I

impl<T> Any for GlobWalker

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for GlobWalker

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for GlobWalker

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for GlobWalker

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Pointable for GlobWalker

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T, U> Into for GlobWalker

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for GlobWalker

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for GlobWalker

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>