Type Alias DirEntry
type DirEntry = DirEntry
A directory entry.
This is the type of value that is yielded from the iterators defined in this crate.
DirEntrytype DirEntry = DirEntry
A directory entry.
This is the type of value that is yielded from the iterators defined in this crate.